#Does Grateful Love Take Two? New insights into Partner Match on Gratitude Using Seven Longitudinal Datasets
#Yoobin Park, Amie M. Gordon, Amy Muise, Emily A. Impett
#Example syntax

#Main analyses#################################
#variable centering 
data<- data %>%
  mutate(agrat_c = agrat - mean(agrat, na.rm=T),
         pgrat_c = pgrat - mean(pgrat, na.rm=T))

#sample is a factor (1=Berkeley; 2=self-expansion; 3=touch; 4=decision making, 5=TCS, 6=SIR, 7=sleep)
#RQ1: actor and partner gratitude interacting to predict baseline satisfaction
model1<- lmer(satisfaction ~ (1|dyad)+sample+agrat_c*pgrat_c, data)

#RQ2: actor and partner gratitude interacting to predict satisfaction at follow-up
model2<- lmer(satisfactionFL ~ (1|dyad)+sample+satisfaction_c+agrat_c*pgrat_c, data)

#RQ3: actor and partner gratitude interacting to predict baseline commitment
model3<- lmer(commitment ~ (1|dyad)+sample+satisfaction_c+agrat_c*pgrat_c, data)

#RQ4: actor and partner gratitude interacting to predict commitment at follow-up
model4<- lmer(commitmentFL ~ (1|dyad)+sample+commitment_c+agrat_c*pgrat_c, data)

#RQ5: actor gratitude at baseline predicting partner's gratitude at folow-up
model5<- lmer(pgratFL ~ (1|dyad)+sample++pgrat_c+agrat_c, data)

#for any significant interactions, simple slope tests will follow:

data<- data %>%
  mutate(pgratH = pgrat_c-sd(pgrat_c, na.rm=T),
         pgratL = pgrat_c+sd(pgrat_c, na.rm=T))

#e.g.,
model1a<- lmer(satisfaction ~ (1|dyad)+sample+agrat_c*pgratH, data)
model1b<- lmer(satisfaction ~ (1|dyad)+sample+agrat_c*pgratL, data)


#Sensitivity analyses#################################
#controlling for gender, age, and relationship length

#RQ1
model1<- lmer(satisfaction ~ (1|dyad)+sample+gender+age_c+relength_c+agrat_c*pgrat_c, data)

#RQ2
model2<- lmer(satisfactionFL ~ (1|dyad)+sample+gender+age_c+relength_c+satisfaction_c+agrat_c*pgrat_c, data)

#RQ3
model3<- lmer(commitment ~ (1|dyad)+sample+gender+age_c+relength_c+satisfaction_c+agrat_c*pgrat_c, data)

#RQ4
model4<- lmer(commitmentFL ~ (1|dyad)+sample+gender+age_c+relength_c+commitment_c+agrat_c*pgrat_c, data)

#RQ5
model5<- lmer(pgratFL ~ (1|dyad)+sample+gender+age_c+relength_c+pgrat_c+agrat_c, data)


#Exploratory analyses#################################
#1) Testing the role of "feeling" appreciated in RQ5
#indirect effect of actor gratitude on partner's follow-up gratitude via partner's feeling appreciated at follow-up

#a path: actor gratitude predicting partner's follow-up "appreciated" (controlling for baseline "appreciated")
modela<- lmer(pappFL ~ (1|dyad)+sample+papp_c+agrat_c, data)

#b path: partner appreciated predicting partner gratitude at follow-up (controlling for baseline gratitude)
modelb<- lmer(pgrat ~ (1|dyad)+sample+papp_c+pappFL+agrat_c , data)

#use monte carlo method to assess mediation (Selig & Preacher, 2008): http://quantpsy.org/medmc/medmc.htm 
#use the link for simularion

#2) Testing the group difference (groups differing in the time between baseline & follow-up surveys)
#group coded as 1=2-week; 2=3-month; 3=6-month
#Berkeley/Self-expansion/Touch/Decision making = 1; TCS = 2; SIR/Sleep = 3

data$group <- recode_factor(data$sample, `1` = "1", `2` = "1", `3` = "1",`4` = "2", `5` = "3", `6` = "3")

#RQ2: actor and partner gratitude interacting to predict satisfaction at follow-up
model2<- lmer(satisfactionFL ~ (1|dyad)+satisfaction_c+agrat_c*pgrat_c*group, data)

#RQ4: actor and partner gratitude interacting to predict commitment at follow-up
model4<- lmer(commitmentFL ~ (1|dyad)+commitment_c+agrat_c*pgrat_c*group, data)

#RQ5: actor gratitude at baseline predicting partner's gratitude at folow-up
model5<- lmer(pgratFL ~ (1|dyad)+pgrat_c+agrat_c*group, data)


